package com.chelvc.cloud.vehicle.api.service;

import com.chelvc.cloud.vehicle.api.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.api.dto.MerchantDetailDTO;
import com.chelvc.cloud.vehicle.api.dto.MerchantRankDTO;
import com.chelvc.cloud.vehicle.api.param.*;
import com.chelvc.framework.common.model.Pagination;

import java.util.List;
import java.util.Map;

/**
 * 商家业务接口
 *
 * @author Woody
 * @date 2023/5/4
 */
public interface MerchantService {
    /**
     * 获取附近商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listNearbyMerchants(LocationQueryParam param, int size);

    /**
     * 获取推荐商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listRecommendMerchants(LocationQueryParam param, int size);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    List<MerchantDTO> listSimpleMerchants(MerchantQueryParam param);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @param param 查询参数
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id, LocationQueryParam param);

    /**
     * 新增商家
     *
     * @param param 新增参数
     * @return 商家主键
     */
    Long addMerchant(MerchantModifyParam param);

    /**
     * 修改商家
     *
     * @param id    商家主键
     * @param param 修改参数
     */
    void updateMerchant(Long id, MerchantModifyParam param);

    /**
     * 删除商家
     *
     * @param id    商家主键
     */
    void deleteMerchant(Long id);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家分页信息
     */
    Pagination<MerchantDTO> getMerchantPaging(MerchantPagingParam param);

    /**
     * 查询商家信息
     *
     * @param id 商家主键
     * @return 商家信息
     */
    MerchantDTO getMerchant(Long id);

    /**
     * 获取商家信息
     * @return
     */
    List<MerchantDTO> getMerchantIdsByUserId();

    /**
     * 查询商家排名
     * @param param
     * @param userId
     * @return
     */
    List<MerchantRankDTO> listRankMerchants(MerchantRankParam param, Long userId);

    /**
     * 我的购物车列表
     * @param param
     * @return
     */
    public Pagination<MerchantDTO> getUserMineCartPaging(OmsCartItemPagingParam param);

    /**
     * 更改商家得营业状态
     * @param merchantId 商家ID
     * @param businessStatus 营业状态
     */
    public void updateMerchantBusinessStatus(Long merchantId,String businessStatus);

    /**
     * 获取商家营业状况
     * @return
     */
    Map<String,Object> operatConditions();

    /**
     * 经营报表
     * @return 经营报表信息
     */
    List<Map<String,Object>> operatReport(ReportModifyParam param);

}



